@@ -3,9 +3,9 @@
 /// See [TypeInfo::Extern](crate::types::TypeInfo::Extern)
 #[macro_export]
 macro_rules! define_extern_type {
-    ($target:ident) => (define_extern_type!($target => $target););
+    ($target:ident) => ($crate::define_extern_type!($target => $target););
     ($target:ty => $defined_path:path) => {
-        impl ::static_reflect::StaticReflect for $target {
+        unsafe impl ::static_reflect::StaticReflect for $target {
             const TYPE_INFO: $crate::TypeInfo<'static> = $crate::TypeInfo::Extern {
                 name: stringify!($defined_path)
             };
